==> deepin-camera_6.5.20.tar.xz: BUILD/src/src/settings_translation.cpp <==
// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: GPL-3.0-or-later

#include <DSettings>

void GenerateSettingTranslate()
{
    auto group_settings = QObject::tr("Settings");
    auto group_baseName = QObject::tr("Basic");
    auto group_base_savaName = QObject::tr("File location");
    auto base_save_picpathName = QObject::tr("Photos:");
    auto base_save_vidpathName = QObject::tr("Videos:");
    auto group_base_gridLines = QObject::tr("Gridlines");
    auto base_1_1_lines = QObject::tr("1*1 lines");
    auto base_2_2_lines = QObject::tr("2*2 lines");
    auto group_photosettingName = QObject::tr("Shoot");
    auto group_photosetting_photosnumberName = QObject::tr("Burst mode");
    auto group_photosetting_photosdelayName = QObject::tr("Self-timer delay");
    auto group_photosetting_mirrorModeName = QObject::tr("Mirror mode");
    auto group_photosetting_FlashlightName = QObject::tr("Flashlight");
    auto group_outsettingName = QObject::tr("Output");
    auto outsetting_audiosetting_soundreminderName = QObject::tr("Sound effects");
    auto group_outsetting_outformatName = QObject::tr("Output format");
    auto outsetting_outformat_picformatName = QObject::tr("Photo:");
    auto outsetting_outformat_vidformatName = QObject::tr("Video:");
    auto outsetting_4pcs = QObject::tr("4 pcs");
    auto outsetting_10pcs = QObject::tr("10 pcs");
    auto outsetting_none = QObject::tr("None");
    auto outsetting_resolutionsettingName = QObject::tr("Resolution settings");
    auto outsetting_resolutionsetting_resolutionName = QObject::tr("Maximum resolution:");
}

==> deepin-camera_6.5.35.tar.xz: BUILD/src/src/settings_translation.cpp <==
// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: GPL-3.0-or-later

#include <DSettings>

void GenerateSettingTranslate()
{
    // qDebug() << "Function started: GenerateSettingTranslate";
    auto group_settings = QObject::tr("Settings");
    auto group_baseName = QObject::tr("Basic");
    auto group_base_savaName = QObject::tr("File location");
    auto base_save_picpathName = QObject::tr("Photos:");
    auto base_save_vidpathName = QObject::tr("Videos:");
    auto group_base_gridLines = QObject::tr("Gridlines");
    auto base_1_1_lines = QObject::tr("1*1 lines");
    auto base_2_2_lines = QObject::tr("2*2 lines");
    auto group_photosettingName = QObject::tr("Shoot");
    auto group_photosetting_photosnumberName = QObject::tr("Burst mode");
    auto group_photosetting_photosdelayName = QObject::tr("Self-timer delay");
    auto group_photosetting_mirrorModeName = QObject::tr("Mirror mode");
    auto group_photosetting_FlashlightName = QObject::tr("Flashlight");
    auto group_outsettingName = QObject::tr("Output");
    auto outsetting_audiosetting_soundreminderName = QObject::tr("Sound effects");
    auto group_outsetting_outformatName = QObject::tr("Output format");
    auto outsetting_outformat_picformatName = QObject::tr("Photo:");
    auto outsetting_outformat_vidformatName = QObject::tr("Video:");
    auto outsetting_4pcs = QObject::tr("4 pcs");
    auto outsetting_10pcs = QObject::tr("10 pcs");
    auto outsetting_none = QObject::tr("None");
    auto outsetting_resolutionsettingName = QObject::tr("Resolution settings");
    auto outsetting_resolutionsetting_resolutionName = QObject::tr("Maximum resolution:");
    // qDebug() << "Function completed: GenerateSettingTranslate";
}
